<?php
/**
 * Dcode Design Settings panel at Theme Customizer
 *
 * @package Dcode
 * @since 1.0.0
 */

add_action( 'customize_register', 'rdcode_design_settings_register' );

function rdcode_design_settings_register( $wp_customize ) {

    /**
     * Add Design Settings Panel
     *
     * @since 1.0.0
     */
    $wp_customize->add_panel(
	    'rdcode_design_settings_panel',
	    array(
	        'priority'       => 25,
	        'capability'     => 'edit_theme_options',
	        'theme_supports' => '',
	        'title'          => esc_html__( 'Design Settings', 'dcode' ),
	    )
    );

    /*---------------------------------------------------------------------------------------------------------------*/
    /**
     * Single Post Settings
     *
     * @since 1.0.0
     */
    $wp_customize->add_section(
        'rdcode_single_post_layout_section',
        array(
            'title'    => esc_html__( 'Single Post Layout', 'dcode' ),
            'panel'    => 'rdcode_design_settings_panel',
            'priority' => 5,
        )
    );

    /**
     * Heding
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'rdcode_heading_single_post_title',
        array(
            'default'           => '',
            'sanitize_callback' => 'wp_kses',
        )
    );
    $wp_customize->add_control( new rdcode_Customizer_Heading(
        $wp_customize,
            'rdcode_heading_single_post_title',
            array(
                'label'    => esc_html__( 'POST TITLE', 'dcode' ),
                'section'  => 'rdcode_single_post_layout_section',
                'priority' => 5,
            )
        )
    );

    $wp_customize->add_setting(
        'rdcode_show_post_title',
        array(
            'default'           => 'show',
            'sanitize_callback' => 'rdcode_sanitize_switch_option',
        )
    );
    $wp_customize->add_control( new rdcode_Customize_Switch_Control(
        $wp_customize,
        'rdcode_show_post_title',
            array(
                'type'        => 'rdcode-switch',
                'label'       => esc_html__( 'Show Post Title', 'dcode' ),
                'section'     => 'rdcode_single_post_layout_section',
                'choices'     => array(
                    'show' => esc_html__( 'Show', 'dcode' ),
                    'hide' => esc_html__( 'Hide', 'dcode' ),
                ),
                'priority'    => 5,
            )
        )
    );

    /**
     * Post title layout
     */
    $wp_customize->add_setting(
        'rdcode_post_title_layout',
        array(
            'default'           => 'above',
            'sanitize_callback' => 'sanitize_key',
        )       
    );
    $wp_customize->add_control(
        new rdcode_Customize_Image_Radio_Control(
            $wp_customize,
            'rdcode_post_title_layout',
            array(
                'type'     => 'rdcode-radio-image',
                'label'    => esc_html__( 'Post Title Layout', 'dcode' ),
                'description' => esc_html__( 'Select Post title position "Above content" or "In Content".', 'dcode' ),
                'section'  => 'rdcode_single_post_layout_section',
                'choices'  => array(
                    'above' => array(
                        'label' => esc_html__( 'Above Content', 'dcode' ),
                        'url'   => '%s/assets/images/customizer/above.png'
                    ),
                    'below' => array(
                        'label' => esc_html__( 'In Content', 'dcode' ),
                        'url'   => '%s/assets/images/customizer/in.png'
                    )
                ),
                'priority' => 5,
            )
        )
    );

    // $wp_customize->add_setting(
    //     'rdcode_single_post_cotainer_width',
    //     array(
    //         'default'           => 'standard',
    //         'sanitize_callback' => 'rdcode_sanitize_switch_option',
    //     )
    // );
    // $wp_customize->add_control( new rdcode_Customize_Switch_Control(
    //     $wp_customize,
    //     'rdcode_single_post_cotainer_width',
    //         array(
    //             'type'        => 'rdcode-switch',
    //             'label'       => esc_html__( 'Container Width', 'dcode' ),
    //             'section'     => 'rdcode_single_post_layout_section',
    //             'choices'     => array(
    //                 'standard'  => esc_html__( 'STANDARD', 'dcode' ),
    //                 'fullwidth' => esc_html__( 'FULLWIDTH', 'dcode' ),
    //                 'contained' => esc_html__( 'CONTAINED', 'dcode' ),
    //             ),
    //             'priority'    => 5,
    //         )
    //     )
    // );

    $wp_customize->add_setting(
        'rdcode_single_title_align',
        array(
            'default'           => 'single_left_align_title',
            'sanitize_callback' => 'sanitize_key',
        )       
    );
    $wp_customize->add_control(
        new rdcode_Customize_Image_Radio_Control(
            $wp_customize,
            'rdcode_single_title_align',
            array(
                'type'     => 'rdcode-radio-image',
                'label'    => esc_html__( 'Post Title Align', 'dcode' ),
                'section'  => 'rdcode_single_post_layout_section',
                'choices'  => array(
                    'single_left_align_title' => array(
                        'label' => esc_html__( 'Left Align Title', 'dcode' ),
                        'url'   => '%s/assets/images/customizer/align-left.png'
                    ),
                    'single_center_align_title' => array(
                        'label' => esc_html__( 'Center Align Title', 'dcode' ),
                        'url'   => '%s/assets/images/customizer/align-center.png'
                    ),
                    'single_right_align_title' => array(
                        'label' => esc_html__( 'Right Align Title', 'dcode' ),
                        'url'   => '%s/assets/images/customizer/align-right.png'
                    )
                ),
                'priority' => 5,
            )
        )
    );

    $wp_customize->add_setting( 'rdcode_single_beadcrumb_height', array(
        'default'           => 100,
        'type'              => 'theme_mod',
        'capability'        => 'edit_theme_options',
        'transport'         => 'postMessage',
        'sanitize_callback' => 'rdcode_sanitize_number_absint',
    ) );

    $wp_customize->add_control( new rdcode_Range_Value_Control(
        $wp_customize,
        'rdcode_single_beadcrumb_height',
        array(
            'type'        => 'rdcode-range-value',
            'label'       => esc_html__( 'Container Min Height', 'dcode' ),
            'section'     => 'rdcode_single_post_layout_section',
            'priority'    => 5,
            'input_attrs' => array(
                'min'    => 0,
                'max'    => 150,
                'step'   => 1,
                'suffix' => 'px',
            ),        
        )
    ));

    /**
     * Heding H6
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'rdcode_heading_single_post_layout',
        array(
            'default'           => '',
            'sanitize_callback' => 'wp_kses',
        )
    );
    $wp_customize->add_control( new rdcode_Customizer_Heading(
        $wp_customize,
            'rdcode_heading_single_post_layout',
            array(
                'label'    => esc_html__( 'DEFAULT POST LAYOUT', 'dcode' ),
                'section'  => 'rdcode_single_post_layout_section',
                'priority' => 5,
            )
        )
    );

    $wp_customize->add_setting(
        'rdcode_single_sidebar_layout',
        array(
            'default'           => 'right_sidebar',
            'sanitize_callback' => 'sanitize_key',
        )       
    );
    $wp_customize->add_control(
        new rdcode_Customize_Image_Radio_Control(
            $wp_customize,
            'rdcode_single_sidebar_layout',
            array(
                'type'     => 'rdcode-radio-image',
                'label'    => esc_html__( 'Default Post( Single post ) Layout', 'dcode' ),
                'section'  => 'rdcode_single_post_layout_section',
                'choices'  => array(
                    'no_sidebar' => array(
                        'label'    => esc_html__( 'Full-width layout', 'dcode' ),
                        'url'      => '%s/assets/images/customizer/full.png'
                    ),
                    'left_sidebar' => array(
                        'label'    => esc_html__( 'Left Sidebar', 'dcode' ),
                        'url'      => '%s/assets/images/customizer/left.png'
                    ),
                    'right_sidebar' => array(
                        'label'     => esc_html__( 'Right Sidebar', 'dcode' ),
                        'url'       => '%s/assets/images/customizer/right.png'
                    )
                ),
                'priority' => 5,
            )
        )
    );

    $wp_customize->add_setting(
        'rdcode_single_default_sidebar',
        array(
            'type'              => 'theme_mod',
            'default'           => 'sidebar-1',
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    $wp_customize->add_control( new WP_Customize_Control(
        $wp_customize,
        'rdcode_single_default_sidebar',
        array(
            'type'        => 'select',
            'label'       => esc_html__( 'Post Default Sidebar', 'dcode' ),
            'section'     => 'rdcode_single_post_layout_section',
            'priority'    => 5,
            'choices'     => array( 
                'sidebar-1' => esc_html__( 'Sidebar 1', 'dcode' ),
                'sidebar-2' => esc_html__( 'Sidebar 2', 'dcode' ),
                'sidebar-3' => esc_html__( 'Sidebar 3', 'dcode' ),
            ),
        )
    ));

    $wp_customize->add_setting(
        'rdcode_single_post_fimage',
        array(
            'default'           => 'show',
            'sanitize_callback' => 'rdcode_sanitize_switch_option',
        )
    );
    $wp_customize->add_control( new rdcode_Customize_Switch_Control(
        $wp_customize,
        'rdcode_single_post_fimage',
            array(
                'type'        => 'rdcode-switch',
                'label'       => esc_html__( 'Show Featured Image', 'dcode' ),
                'section'     => 'rdcode_single_post_layout_section',
                'choices'     => array(
                    'show'  => esc_html__( 'Show', 'dcode' ),
                    'hide' => esc_html__( 'Hide', 'dcode' ),
                ),
                'priority'    => 5,
            )
        )
    );

    /**
     * Heding
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'rdcode_single_meta_post_head',
        array(
            'default'           => '',
            'sanitize_callback' => 'wp_kses',
            )
    );
    $wp_customize->add_control( new rdcode_Customizer_Heading(
        $wp_customize,
            'rdcode_single_meta_post_head',
            array(
                'label'    => esc_html__( 'POST META', 'dcode' ),
                'section'  => 'rdcode_single_post_layout_section',
                'priority' => 5,
            )
        )
    );

    $wp_customize->add_setting(
        'rdcode_single_post_author',
        array(
            'default'           => 'show',
            'sanitize_callback' => 'rdcode_sanitize_switch_option',
        )
    );
    $wp_customize->add_control( new rdcode_Customize_Switch_Control(
        $wp_customize,
        'rdcode_single_post_author',
            array(
                'type'        => 'rdcode-switch',
                'label'       => esc_html__( 'Show Post Author Name?', 'dcode' ),
                'section'     => 'rdcode_single_post_layout_section',
                'choices'     => array(
                    'show'  => esc_html__( 'Show', 'dcode' ),
                    'hide' => esc_html__( 'Hide', 'dcode' ),
                ),
                'priority'    => 5,
            )
        )
    );

    $wp_customize->add_setting(
        'rdcode_single_post_date',
        array(
            'default'           => 'show',
            'sanitize_callback' => 'rdcode_sanitize_switch_option',
        )
    );
    $wp_customize->add_control( new rdcode_Customize_Switch_Control(
        $wp_customize,
        'rdcode_single_post_date',
            array(
                'type'        => 'rdcode-switch',
                'label'       => esc_html__( 'Show Post Date?', 'dcode' ),
                'section'     => 'rdcode_single_post_layout_section',
                'choices'     => array(
                    'show'  => esc_html__( 'Show', 'dcode' ),
                    'hide' => esc_html__( 'Hide', 'dcode' ),
                ),
                'priority'    => 5,
            )
        )
    );

    $wp_customize->add_setting(
        'rdcode_single_post_comment_count',
        array(
            'default'           => 'show',
            'sanitize_callback' => 'rdcode_sanitize_switch_option',
        )
    );
    $wp_customize->add_control( new rdcode_Customize_Switch_Control(
        $wp_customize,
        'rdcode_single_post_comment_count',
            array(
                'type'        => 'rdcode-switch',
                'label'       => esc_html__( 'Show Post Comment Count?', 'dcode' ),
                'section'     => 'rdcode_single_post_layout_section',
                'choices'     => array(
                    'show'  => esc_html__( 'Show', 'dcode' ),
                    'hide' => esc_html__( 'Hide', 'dcode' ),
                ),
                'priority'    => 5,
            )
        )
    );

    $wp_customize->add_setting(
        'rdcode_single_post_tags',
        array(
            'default'           => 'show',
            'sanitize_callback' => 'rdcode_sanitize_switch_option',
        )
    );
    $wp_customize->add_control( new rdcode_Customize_Switch_Control(
        $wp_customize,
        'rdcode_single_post_tags',
            array(
                'type'        => 'rdcode-switch',
                'label'       => esc_html__( 'Show Post Tags?', 'dcode' ),
                'section'     => 'rdcode_single_post_layout_section',
                'choices'     => array(
                    'show' => esc_html__( 'Show', 'dcode' ),
                    'hide' => esc_html__( 'Hide', 'dcode' ),
                ),
                'priority'    => 5,
            )
        )
    );

    $wp_customize->add_setting(
        'rdcode_single_post_categories',
        array(
            'default'           => 'show',
            'sanitize_callback' => 'rdcode_sanitize_switch_option',
        )
    );
    $wp_customize->add_control( new rdcode_Customize_Switch_Control(
        $wp_customize,
        'rdcode_single_post_categories',
            array(
                'type'        => 'rdcode-switch',
                'label'       => esc_html__( 'Show Post Categories?', 'dcode' ),
                'section'     => 'rdcode_single_post_layout_section',
                'choices'     => array(
                    'show' => esc_html__( 'Show', 'dcode' ),
                    'hide' => esc_html__( 'Hide', 'dcode' ),
                ),
                'priority'    => 5,
            )
        )
    );

    $wp_customize->add_setting(
        'rdcode_single_post_author_box',
        array(
            'default'           => 'show',
            'sanitize_callback' => 'rdcode_sanitize_switch_option',
        )
    );
    $wp_customize->add_control( new rdcode_Customize_Switch_Control(
        $wp_customize,
        'rdcode_single_post_author_box',
            array(
                'type'        => 'rdcode-switch',
                'label'       => esc_html__( 'Show Post Author Box?', 'dcode' ),
                'section'     => 'rdcode_single_post_layout_section',
                'choices'     => array(
                    'show'  => esc_html__( 'Show', 'dcode' ),
                    'hide' => esc_html__( 'Hide', 'dcode' ),
                ),
                'priority'    => 5,
            )
        )
    );

    $wp_customize->add_setting(
        'rdcode_single_post_comments',
        array(
            'default'           => 'show',
            'sanitize_callback' => 'rdcode_sanitize_switch_option',
        )
    );
    $wp_customize->add_control( new rdcode_Customize_Switch_Control(
        $wp_customize,
        'rdcode_single_post_comments',
            array(
                'type'        => 'rdcode-switch',
                'label'       => esc_html__( 'Show Comments?', 'dcode' ),
                'section'     => 'rdcode_single_post_layout_section',
                'choices'     => array(
                    'show'  => esc_html__( 'Show', 'dcode' ),
                    'hide' => esc_html__( 'Hide', 'dcode' ),
                ),
                'priority'    => 5,
            )
        )
    );

    $wp_customize->add_setting(
        'rdcode_single_post_navigation',
        array(
            'default'           => 'show',
            'sanitize_callback' => 'rdcode_sanitize_switch_option',
        )
    );
    $wp_customize->add_control( new rdcode_Customize_Switch_Control(
        $wp_customize,
        'rdcode_single_post_navigation',
            array(
                'type'        => 'rdcode-switch',
                'label'       => esc_html__( 'Show Post Navigation?', 'dcode' ),
                'section'     => 'rdcode_single_post_layout_section',
                'choices'     => array(
                    'show'  => esc_html__( 'Show', 'dcode' ),
                    'hide' => esc_html__( 'Hide', 'dcode' ),
                ),
                'priority'    => 5,
            )
        )
    );

    /**
     * Heding
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'rdcode_single_related_post_head',
        array(
            'default'           => '',
            'sanitize_callback' => 'wp_kses',
            )
    );
    $wp_customize->add_control( new rdcode_Customizer_Heading(
        $wp_customize,
            'rdcode_single_related_post_head',
            array(
                'label'    => esc_html__( 'RELATED POSTS', 'dcode' ),
                'section'  => 'rdcode_single_post_layout_section',
                'priority' => 5,
            )
        )
    );

    $wp_customize->add_setting(
        'rdcode_single_related_posts',
        array(
            'default'           => 'show',
            'sanitize_callback' => 'rdcode_sanitize_switch_option',
        )
    );
    $wp_customize->add_control( new rdcode_Customize_Switch_Control(
        $wp_customize,
        'rdcode_single_related_posts',
            array(
                'type'        => 'rdcode-switch',
                'label'       => esc_html__( 'Show Related Posts?', 'dcode' ),
                'section'     => 'rdcode_single_post_layout_section',
                'choices'     => array(
                    'show'  => esc_html__( 'Show', 'dcode' ),
                    'hide' => esc_html__( 'Hide', 'dcode' ),
                ),
                'priority'    => 5,
            )
        )
    );

    $wp_customize->add_setting(
        'rdcode_single_related_col',
        array(
            'type'              => 'theme_mod',
            'default'           => 'col-lg-6',
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    $wp_customize->add_control( new WP_Customize_Control(
        $wp_customize,
        'rdcode_single_related_col',
        array(
            'type'        => 'select',
            'label'       => esc_html__( 'Related Posts Columns', 'dcode' ),
            'section'     => 'rdcode_single_post_layout_section',
            'priority'    => 5,
            'choices'     => array( 
                'col-lg-6' => esc_html__( '2 Col', 'dcode' ),
                'col-lg-4' => esc_html__( '3 Col', 'dcode' ),
                'col-lg-3' => esc_html__( '4 Col', 'dcode' ),
            ),
        )
    ));

    /*---------------------------------------------------------------------------------------------------------------*/

    /**
     * Archive Settings
     *
     * @since 1.0.0
     */
    $wp_customize->add_section(
        'rdcode_archive_settings_section',
        array(
            'title'    => esc_html__( 'Archive Layout', 'dcode' ),
            'panel'    => 'rdcode_design_settings_panel',
            'priority' => 5,
        )
    );

    /**
     * Heding
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'rdcode_archive_heading',
        array(
            'default'           => '',
            'sanitize_callback' => 'wp_kses',
            )
    );
    $wp_customize->add_control( new rdcode_Customizer_Heading(
        $wp_customize,
            'rdcode_archive_heading',
            array(
                'label'    => esc_html__( 'Archive Title', 'dcode' ),
                'section'  => 'rdcode_archive_settings_section',
                'priority' => 5,
            )
        )
    );

    $wp_customize->add_setting(
        'rdcode_show_archive_title',
        array(
            'default'           => 'show',
            'sanitize_callback' => 'rdcode_sanitize_switch_option',
        )
    );
    $wp_customize->add_control( new rdcode_Customize_Switch_Control(
        $wp_customize,
        'rdcode_show_archive_title',
            array(
                'type'        => 'rdcode-switch',
                'label'       => esc_html__( 'Show Archive Title', 'dcode' ),
                'section'     => 'rdcode_archive_settings_section',
                'choices'     => array(
                    'show' => esc_html__( 'Show', 'dcode' ),
                    'hide' => esc_html__( 'Hide', 'dcode' ),
                ),
                'priority'    => 5,
            )
        )
    );

    /**
     * Archive title layout
     */
    $wp_customize->add_setting(
        'rdcode_archive_title_layout',
        array(
            'default'           => 'above',
            'sanitize_callback' => 'sanitize_key',
        )       
    );
    $wp_customize->add_control(
        new rdcode_Customize_Image_Radio_Control(
            $wp_customize,
            'rdcode_archive_title_layout',
            array(
                'type'     => 'rdcode-radio-image',
                'label'    => esc_html__( 'Archive Title Layout', 'dcode' ),
                'description' => esc_html__( 'Select Archive title position "Above content" or "In Content".', 'dcode' ),
                'section'  => 'rdcode_archive_settings_section',
                'choices'  => array(
                    'above' => array(
                        'label' => esc_html__( 'Above Content', 'dcode' ),
                        'url'   => '%s/assets/images/customizer/above.png'
                    ),
                    'below' => array(
                        'label' => esc_html__( 'In Content', 'dcode' ),
                        'url'   => '%s/assets/images/customizer/in.png'
                    )
                ),
                'priority' => 5,
            )
        )
    );

    // $wp_customize->add_setting(
    //     'rdcode_archive_post_cotainer_width',
    //     array(
    //         'default'           => 'standard',
    //         'sanitize_callback' => 'rdcode_sanitize_switch_option',
    //     )
    // );
    // $wp_customize->add_control( new rdcode_Customize_Switch_Control(
    //     $wp_customize,
    //     'rdcode_archive_post_cotainer_width',
    //         array(
    //             'type'        => 'rdcode-switch',
    //             'label'       => esc_html__( 'Container Width', 'dcode' ),
    //             'section'     => 'rdcode_archive_settings_section',
    //             'choices'     => array(
    //                 'standard'  => esc_html__( 'STANDARD', 'dcode' ),
    //                 'fullwidth' => esc_html__( 'FULLWIDTH', 'dcode' ),
    //                 'contained' => esc_html__( 'CONTAINED', 'dcode' ),
    //             ),
    //             'priority'    => 5,
    //         )
    //     )
    // );

    $wp_customize->add_setting(
        'rdcode_archive_title_align',
        array(
            'default'           => 'single_left_align_title',
            'sanitize_callback' => 'sanitize_key',
        )       
    );
    $wp_customize->add_control(
        new rdcode_Customize_Image_Radio_Control(
            $wp_customize,
            'rdcode_archive_title_align',
            array(
                'type'     => 'rdcode-radio-image',
                'label'    => esc_html__( 'Archive Title Align', 'dcode' ),
                'section'  => 'rdcode_archive_settings_section',
                'choices'  => array(
                    'single_left_align_title' => array(
                        'label' => esc_html__( 'Left Align Title', 'dcode' ),
                        'url'   => '%s/assets/images/customizer/align-left.png'
                    ),
                    'single_center_align_title' => array(
                        'label' => esc_html__( 'Center Align Title', 'dcode' ),
                        'url'   => '%s/assets/images/customizer/align-center.png'
                    ),
                    'single_right_align_title' => array(
                        'label' => esc_html__( 'Right Align Title', 'dcode' ),
                        'url'   => '%s/assets/images/customizer/align-right.png'
                    )
                ),
                'priority' => 5,
            )
        )
    );

    $wp_customize->add_setting( 'rdcode_archive_beadcrumb_height', array(
        'default'           => 100,
        'type'              => 'theme_mod',
        'capability'        => 'edit_theme_options',
        'transport'         => 'postMessage',
        'sanitize_callback' => 'rdcode_sanitize_number_absint',
    ) );

    $wp_customize->add_control( new rdcode_Range_Value_Control(
        $wp_customize,
        'rdcode_archive_beadcrumb_height',
        array(
            'type'        => 'rdcode-range-value',
            'label'       => esc_html__( 'Container Min Height', 'dcode' ),
            'section'     => 'rdcode_archive_settings_section',
            'priority'    => 5,
            'input_attrs' => array(
                'min'    => 0,
                'max'    => 150,
                'step'   => 1,
                'suffix' => 'px',
            ),        
        )
    ));

    /**
     * Heding
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'rdcode_archive_layout_heading',
        array(
            'default'           => '',
            'sanitize_callback' => 'wp_kses',
            )
    );
    $wp_customize->add_control( new rdcode_Customizer_Heading(
        $wp_customize,
            'rdcode_archive_layout_heading',
            array(
                'label'    => esc_html__( 'Default Archive Layout', 'dcode' ),
                'section'  => 'rdcode_archive_settings_section',
                'priority' => 5,
            )
        )
    );

    $wp_customize->add_setting(
        'rdcode_blog_sidebar_layout',
        array(
            'default'           => 'right_sidebar',
            'sanitize_callback' => 'sanitize_key',
        )       
    );
    $wp_customize->add_control(
        new rdcode_Customize_Image_Radio_Control(
            $wp_customize,
            'rdcode_blog_sidebar_layout',
            array(
                'type'     => 'rdcode-radio-image',
                'label'    => esc_html__( 'Archive Sidebar Layout', 'dcode' ),
                'section'  => 'rdcode_archive_settings_section',
                'choices'  => array(
                    'no_sidebar' => array(
                        'label'    => esc_html__( 'Full-width layout', 'dcode' ),
                        'url'      => '%s/assets/images/customizer/full.png'
                    ),
                    'left_sidebar' => array(
                        'label'    => esc_html__( 'Left Sidebar', 'dcode' ),
                        'url'      => '%s/assets/images/customizer/left.png'
                    ),
                    'right_sidebar' => array(
                        'label'     => esc_html__( 'Right Sidebar', 'dcode' ),
                        'url'       => '%s/assets/images/customizer/right.png'
                    )
                ),
                'priority' => 5,
            )
        )
    );

    /**
     * Heding
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'rdcode_meta_tags_heading',
        array(
            'default'           => '',
            'sanitize_callback' => 'wp_kses',
            )
    );
    $wp_customize->add_control( new rdcode_Customizer_Heading(
        $wp_customize,
            'rdcode_meta_tags_heading',
            array(
                'label'    => esc_html__( 'Meta Tags Options', 'dcode' ),
                'section'  => 'rdcode_archive_settings_section',
                'priority' => 5,
            )
        )
    );

    $wp_customize->add_setting(
        'rdcode_show_archive_fimage',
        array(
            'default'           => 'show',
            'sanitize_callback' => 'rdcode_sanitize_switch_option',
            )
    );
    $wp_customize->add_control( new rdcode_Customize_Switch_Control(
        $wp_customize,
            'rdcode_show_archive_fimage',
            array(
                'type'          => 'rdcode-switch',
                'label'         => esc_html__( 'Show Feature Image?', 'dcode' ),
                'description'   => esc_html__( 'Show/Hide option for "Image" for post.', 'dcode' ),
                'section'       => 'rdcode_archive_settings_section',
                'choices'       => array(
                    'show'      => esc_html__( 'Show', 'dcode' ),
                    'hide'      => esc_html__( 'Hide', 'dcode' )
                ),
                'priority'      => 5,
            )
        )
    );

    /**
     * Switch option for Author name
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'rdcode_show_author_name',
        array(
            'default'           => 'show',
            'sanitize_callback' => 'rdcode_sanitize_switch_option',
            )
    );
    $wp_customize->add_control( new rdcode_Customize_Switch_Control(
        $wp_customize,
            'rdcode_show_author_name',
            array(
                'type'          => 'rdcode-switch',
                'label'         => esc_html__( 'Author Name and Icon', 'dcode' ),
                'description'   => esc_html__( 'Show/Hide option for "Author" for post.', 'dcode' ),
                'section'       => 'rdcode_archive_settings_section',
                'choices'       => array(
                    'show'      => esc_html__( 'Show', 'dcode' ),
                    'hide'      => esc_html__( 'Hide', 'dcode' )
                ),
                'priority'      => 5,
            )
        )
    );

    /**
     * Switch option for Post date
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'rdcode_show_post_date',
        array(
            'default'           => 'show',
            'sanitize_callback' => 'rdcode_sanitize_switch_option',
            )
    );
    $wp_customize->add_control( new rdcode_Customize_Switch_Control(
        $wp_customize,
            'rdcode_show_post_date',
            array(
                'type'          => 'rdcode-switch',
                'label'         => esc_html__( 'Post Date and Icon', 'dcode' ),
                'description'   => esc_html__( 'Show/Hide option for "Post date" for post.', 'dcode' ),
                'section'       => 'rdcode_archive_settings_section',
                'choices'       => array(
                    'show'      => esc_html__( 'Show', 'dcode' ),
                    'hide'      => esc_html__( 'Hide', 'dcode' )
                ),
                'priority'      => 5,
            )
        )
    );

     /**
     * Switch option for Post date
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'rdcode_show_comment_count',
        array(
            'default'           => 'show',
            'sanitize_callback' => 'rdcode_sanitize_switch_option',
            )
    );
    $wp_customize->add_control( new rdcode_Customize_Switch_Control(
        $wp_customize,
            'rdcode_show_comment_count',
            array(
                'type'          => 'rdcode-switch',
                'label'         => esc_html__( 'Comment Count and Icon', 'dcode' ),
                'description'   => esc_html__( 'Show/Hide option for "Comment Count" for post.', 'dcode' ),
                'section'       => 'rdcode_archive_settings_section',
                'choices'       => array(
                    'show'      => esc_html__( 'Show', 'dcode' ),
                    'hide'      => esc_html__( 'Hide', 'dcode' )
                ),
                'priority'      => 5,
            )
        )
    );

    $wp_customize->add_setting(
        'rdcode_show_archive_excerpt',
        array(
            'default'           => 'show',
            'sanitize_callback' => 'rdcode_sanitize_switch_option',
            )
    );
    $wp_customize->add_control( new rdcode_Customize_Switch_Control(
        $wp_customize,
            'rdcode_show_archive_excerpt',
            array(
                'type'          => 'rdcode-switch',
                'label'         => esc_html__( 'Show Excerpt?', 'dcode' ),
                'description'   => esc_html__( 'Show/Hide option for "Excerpt" for post.', 'dcode' ),
                'section'       => 'rdcode_archive_settings_section',
                'choices'       => array(
                    'show'      => esc_html__( 'Show', 'dcode' ),
                    'hide'      => esc_html__( 'Hide', 'dcode' )
                ),
                'priority'      => 5,
            )
        )
    );

    $wp_customize->add_setting(
        'rdcode_show_archive_readmore',
        array(
            'default'           => 'show',
            'sanitize_callback' => 'rdcode_sanitize_switch_option',
            )
    );
    $wp_customize->add_control( new rdcode_Customize_Switch_Control(
        $wp_customize,
            'rdcode_show_archive_readmore',
            array(
                'type'          => 'rdcode-switch',
                'label'         => esc_html__( 'Show Readmore Button?', 'dcode' ),
                'description'   => esc_html__( 'Show/Hide option for "Readmore link" for post.', 'dcode' ),
                'section'       => 'rdcode_archive_settings_section',
                'choices'       => array(
                    'show'      => esc_html__( 'Show', 'dcode' ),
                    'hide'      => esc_html__( 'Hide', 'dcode' )
                ),
                'priority'      => 5,
            )
        )
    );

    /**
     * Heding
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'rdcode_post_display_heading',
        array(
            'default'           => '',
            'sanitize_callback' => 'wp_kses',
            )
    );
    $wp_customize->add_control( new rdcode_Customizer_Heading(
        $wp_customize,
            'rdcode_post_display_heading',
            array(
                'label'    => esc_html__( 'Post Display Options', 'dcode' ),
                'section'  => 'rdcode_archive_settings_section',
                'priority' => 5,
            )
        )
    );

    /**
     * Text field for post excerpt length
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'rdcode_blog_excerpt_length',
        array(
            'default'           => 30,
            'sanitize_callback' => 'rdcode_sanitize_number_absint'
            )
    );
    $wp_customize->add_control(
        'rdcode_blog_excerpt_length',
        array(
            'type'         => 'number',
            'label'        => esc_html__( 'Post excerpt length( content length )', 'dcode' ),
            'description'  => esc_html__( 'Enter content length in numbers.', 'dcode' ),
            'section'      => 'rdcode_archive_settings_section',
            'priority'     => 15
        )
    );

    /**
     * Text field for archive read more
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'rdcode_archive_read_more_text',
        array(
            'default'           => esc_html__( 'Read More', 'dcode' ),
            'transport'         => 'postMessage',
            'sanitize_callback' => 'sanitize_text_field'
            )
    );
    $wp_customize->add_control(
        'rdcode_archive_read_more_text',
        array(
            'type'         => 'text',
            'label'        => esc_html__( 'Read More Text', 'dcode' ),
            'description'  => esc_html__( 'Enter read more button text for archive page.', 'dcode' ),
            'section'      => 'rdcode_archive_settings_section',
            'priority'     => 15
        )
    );
    $wp_customize->selective_refresh->add_partial( 
        'rdcode_archive_read_more_text', 
            array(
                'selector'        => '.card.post a.btn.btn-xs.btn-primary',
                'render_callback' => 'rdcode_customize_partial_archive_more',
            )
    );

    /**
     * Radio field for post pagination
     * 
     *  @since 1.0.0
     */
    $wp_customize->add_setting( 
        'rdcode_radio_post_pagination',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => 'pagination',
            'sanitize_callback' => 'rdcode_sanitize_radio_option',
        ) 
    );
    $wp_customize->add_control( 
        'rdcode_radio_post_pagination',
        array(
            'type'        => 'radio',
            'section'     => 'rdcode_archive_settings_section',
            'priority'    => 20,
            'label'       => esc_html__( 'Post Pagination', 'dcode' ),
            'description' => esc_html__( 'Select pagination for post.', 'dcode' ),
            'choices'     => array(
                'default'    => esc_html__( 'default', 'dcode' ),
                'pagination' => esc_html__( 'Pagination', 'dcode' )
            ),
        )
    );
    $wp_customize->selective_refresh->add_partial( 
        'rdcode_radio_post_pagination', 
            array(
                'selector'        => '.pagination-outer',
                'render_callback' => 'rdcode_customize_partial_pagination',
            )
    );

    /*---------------------------------------------------------------------------------------------------------------*/

    /**
     * Page Settings
     *
     * @since 1.0.0
     */
    $wp_customize->add_section(
        'rdcode_page_layout_section',
        array(
            'title'    => esc_html__( 'Page Layout', 'dcode' ),
            'panel'    => 'rdcode_design_settings_panel',
            'priority' => 5,
        )
    );

    /**
     * Heding
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'rdcode_heading_single_page_title',
        array(
            'default'           => '',
            'sanitize_callback' => 'wp_kses',
        )
    );
    $wp_customize->add_control( new rdcode_Customizer_Heading(
        $wp_customize,
            'rdcode_heading_single_page_title',
            array(
                'label'    => esc_html__( 'PAGE TITLE', 'dcode' ),
                'section'  => 'rdcode_page_layout_section',
                'priority' => 5,
            )
        )
    );

    $wp_customize->add_setting(
        'rdcode_show_page_title',
        array(
            'default'           => 'show',
            'sanitize_callback' => 'rdcode_sanitize_switch_option',
        )
    );
    $wp_customize->add_control( new rdcode_Customize_Switch_Control(
        $wp_customize,
        'rdcode_show_page_title',
            array(
                'type'        => 'rdcode-switch',
                'label'       => esc_html__( 'Show Page Title', 'dcode' ),
                'section'     => 'rdcode_page_layout_section',
                'choices'     => array(
                    'show' => esc_html__( 'Show', 'dcode' ),
                    'hide' => esc_html__( 'Hide', 'dcode' ),
                ),
                'priority'    => 5,
            )
        )
    );

    /**
     * Page title layout
     */
    $wp_customize->add_setting(
        'rdcode_page_title_layout',
        array(
            'default'           => 'above',
            'sanitize_callback' => 'sanitize_key',
        )       
    );
    $wp_customize->add_control(
        new rdcode_Customize_Image_Radio_Control(
            $wp_customize,
            'rdcode_page_title_layout',
            array(
                'type'     => 'rdcode-radio-image',
                'label'    => esc_html__( 'Page Title Layout', 'dcode' ),
                'description' => esc_html__( 'Select Page title position "Above content" or "In Content".', 'dcode' ),
                'section'  => 'rdcode_page_layout_section',
                'choices'  => array(
                    'above' => array(
                        'label' => esc_html__( 'Above Content', 'dcode' ),
                        'url'   => '%s/assets/images/customizer/above.png'
                    ),
                    'below' => array(
                        'label' => esc_html__( 'In Content', 'dcode' ),
                        'url'   => '%s/assets/images/customizer/in.png'
                    )
                ),
                'priority' => 5,
            )
        )
    );

    // $wp_customize->add_setting(
    //     'rdcode_single_page_cotainer_width',
    //     array(
    //         'default'           => 'standard',
    //         'sanitize_callback' => 'rdcode_sanitize_switch_option',
    //     )
    // );
    // $wp_customize->add_control( new rdcode_Customize_Switch_Control(
    //     $wp_customize,
    //     'rdcode_single_page_cotainer_width',
    //         array(
    //             'type'        => 'rdcode-switch',
    //             'label'       => esc_html__( 'Container Width', 'dcode' ),
    //             'section'     => 'rdcode_page_layout_section',
    //             'choices'     => array(
    //                 'standard'  => esc_html__( 'STANDARD', 'dcode' ),
    //                 'fullwidth' => esc_html__( 'FULLWIDTH', 'dcode' ),
    //                 'contained' => esc_html__( 'CONTAINED', 'dcode' ),
    //             ),
    //             'priority'    => 5,
    //         )
    //     )
    // );

    $wp_customize->add_setting(
        'rdcode_single_page_title_align',
        array(
            'default'           => 'single_left_align_title',
            'sanitize_callback' => 'sanitize_key',
        )       
    );
    $wp_customize->add_control(
        new rdcode_Customize_Image_Radio_Control(
            $wp_customize,
            'rdcode_single_page_title_align',
            array(
                'type'     => 'rdcode-radio-image',
                'label'    => esc_html__( 'Page Title Align', 'dcode' ),
                'section'  => 'rdcode_page_layout_section',
                'choices'  => array(
                    'single_left_align_title' => array(
                        'label' => esc_html__( 'Left Align Title', 'dcode' ),
                        'url'   => '%s/assets/images/customizer/align-left.png'
                    ),
                    'single_center_align_title' => array(
                        'label' => esc_html__( 'Center Align Title', 'dcode' ),
                        'url'   => '%s/assets/images/customizer/align-center.png'
                    ),
                    'single_right_align_title' => array(
                        'label' => esc_html__( 'Right Align Title', 'dcode' ),
                        'url'   => '%s/assets/images/customizer/align-right.png'
                    )
                ),
                'priority' => 5,
            )
        )
    );

    $wp_customize->add_setting( 'rdcode_single_page_beadcrumb_height', array(
        'default'           => 100,
        'type'              => 'theme_mod',
        'capability'        => 'edit_theme_options',
        'transport'         => 'postMessage',
        'sanitize_callback' => 'rdcode_sanitize_number_absint',
    ) );

    $wp_customize->add_control( new rdcode_Range_Value_Control(
        $wp_customize,
        'rdcode_single_page_beadcrumb_height',
        array(
            'type'        => 'rdcode-range-value',
            'label'       => esc_html__( 'Container Min Height', 'dcode' ),
            'section'     => 'rdcode_page_layout_section',
            'priority'    => 5,
            'input_attrs' => array(
                'min'    => 0,
                'max'    => 150,
                'step'   => 1,
                'suffix' => 'px',
            ),        
        )
    ));

    /**
     * Heding 
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'rdcode_heading_single_page_layout',
        array(
            'default'           => '',
            'sanitize_callback' => 'wp_kses',
        )
    );
    $wp_customize->add_control( new rdcode_Customizer_Heading(
        $wp_customize,
            'rdcode_heading_single_page_layout',
            array(
                'label'    => esc_html__( 'DEFAULT PAGE LAYOUT', 'dcode' ),
                'section'  => 'rdcode_page_layout_section',
                'priority' => 5,
            )
        )
    );

    /**
     * page sidebar layout
     */
    $wp_customize->add_setting(
        'rdcode_page_sidebar_layout',
        array(
            'default'           => 'right_sidebar',
            'sanitize_callback' => 'sanitize_key',
        )       
    );
    $wp_customize->add_control(
        new rdcode_Customize_Image_Radio_Control(
            $wp_customize,
            'rdcode_page_sidebar_layout',
            array(
                'type'     => 'rdcode-radio-image',
                'label'    => esc_html__( 'Page Layout', 'dcode' ),
                'section'  => 'rdcode_page_layout_section',
                'choices'  => array(
                    'no_sidebar' => array(
                        'label'    => esc_html__( 'Full width layout', 'dcode' ),
                        'url'      => '%s/assets/images/customizer/full.png'
                    ),
                    'left_sidebar' => array(
                        'label'    => esc_html__( 'Left Sidebar', 'dcode' ),
                        'url'      => '%s/assets/images/customizer/left.png'
                    ),
                    'right_sidebar' => array(
                        'label'     => esc_html__( 'Right Sidebar', 'dcode' ),
                        'url'       => '%s/assets/images/customizer/right.png'
                    )
                ),
                'priority' => 5,
            )
        )
    );

    $wp_customize->add_setting(
        'rdcode_single_page_default_sidebar',
        array(
            'type'              => 'theme_mod',
            'default'           => 'sidebar-1',
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    $wp_customize->add_control( new WP_Customize_Control(
        $wp_customize,
        'rdcode_single_page_default_sidebar',
        array(
            'type'        => 'select',
            'label'       => esc_html__( 'Page Default Sidebar', 'dcode' ),
            'section'     => 'rdcode_page_layout_section',
            'priority'    => 5,
            'choices'     => array( 
                'sidebar-1' => esc_html__( 'Sidebar 1', 'dcode' ),
                'sidebar-2' => esc_html__( 'Sidebar 2', 'dcode' ),
                'sidebar-3' => esc_html__( 'Sidebar 3', 'dcode' ),
            ),
        )
    ));

    $wp_customize->add_setting(
        'rdcode_single_page_fimage',
        array(
            'default'           => 'show',
            'sanitize_callback' => 'rdcode_sanitize_switch_option',
        )
    );
    $wp_customize->add_control( new rdcode_Customize_Switch_Control(
        $wp_customize,
        'rdcode_single_page_fimage',
            array(
                'type'        => 'rdcode-switch',
                'label'       => esc_html__( 'Show Featured Image', 'dcode' ),
                'section'     => 'rdcode_page_layout_section',
                'choices'     => array(
                    'show' => esc_html__( 'Show', 'dcode' ),
                    'hide' => esc_html__( 'Hide', 'dcode' ),
                ),
                'priority'    => 5,
            )
        )
    );

    $wp_customize->add_setting(
        'rdcode_single_page_comments',
        array(
            'default'           => 'show',
            'sanitize_callback' => 'rdcode_sanitize_switch_option',
        )
    );
    $wp_customize->add_control( new rdcode_Customize_Switch_Control(
        $wp_customize,
        'rdcode_single_page_comments',
            array(
                'type'        => 'rdcode-switch',
                'label'       => esc_html__( 'Show Comments', 'dcode' ),
                'section'     => 'rdcode_page_layout_section',
                'choices'     => array(
                    'show' => esc_html__( 'Show', 'dcode' ),
                    'hide' => esc_html__( 'Hide', 'dcode' ),
                ),
                'priority'    => 5,
            )
        )
    );

    /*---------------------------------------------------------------------------------------------------------------*/
}