<?php
/**
 * Custom hooks functions are define.
 *
 * @package Dcode
 * @since 1.0.0
 */

/*-----------------------------------------------------------------------------------------------------------------------*/

/**
 * Site preloader.
 *
 */
if( ! function_exists( 'rdcode_preloader' ) ) :

	/**
	 * Fav icon
	 *
	 * @since 1.0.0
	 */
	function rdcode_preloader() {
		?>
		<!--preloader-->
	    <div class="preloader" id="preloader">
	        <div class="preloader_inner">
			<div class="loader">
				<div class="square"></div>
				<div class="path">
					<div></div>
					<div></div>
					<div></div>
					<div></div>
					<div></div>
					<div></div>
					<div></div>
				</div>
			<p class="text-load">Loading</p>
			</div>
	        </div>
	    </div>
	    <?php
	}

endif;

/*-----------------------------------------------------------------------------------------------------------------------*/

/**
 * Post readmore text.
 *
 */
if( ! function_exists( 'rdcode_readmore_txt' ) ) :

	function rdcode_readmore_txt() {
		if ( ! empty ( get_theme_mod( 'rdcode_archive_read_more_text', 'Readmore' ) ) ) {
			$readmore_txt = get_theme_mod( 'rdcode_archive_read_more_text', 'Readmore' );
		} else {
			$readmore_txt = '';
		}
		?>
		<!--readmore button-->
		<a href="<?php the_permalink(); ?>" class="btn btn-xs btn-primary">
			<?php 
				echo esc_html ( $readmore_txt );
			?>
		</a>
		<?php
	}

endif;

/*-----------------------------------------------------------------------------------------------------------------------*/

/**
 * Post pagination layout.
 *
 */
if( ! function_exists( 'rdcode_post_pagination_call' ) ) :

	function rdcode_post_pagination_call() {
		?>
		<!--Post pagination-->
		<div class="row">
            <?php if ( get_theme_mod( 'rdcode_radio_post_pagination', 'pagination' ) == 'default' ) {
                    $class = 'default';
                } else {
                    $class = '';
                }
            ?>
            <div class="col-md-12 pagination-outer <?php echo esc_attr( $class ); ?>">
                <?php
                    if ( get_theme_mod( 'rdcode_radio_post_pagination', 'pagination' ) == 'default' ) {
                        the_posts_navigation();
                    } elseif ( get_theme_mod( 'rdcode_radio_post_pagination', 'pagination' ) == 'pagination' ) {
                        echo wp_kses_post( the_posts_pagination( array( 'mid_size' => 2) ) );
					}
                ?>
            </div>
        </div>
		<?php
	}

endif;

/*-----------------------------------------------------------------------------------------------------------------------*/

/**
 * Page side bar layout.
 *
 */
if( ! function_exists( 'rdcode_page_sidebar_layout' ) ) :

	function rdcode_page_sidebar_layout() {

		if ( get_theme_mod( 'rdcode_page_sidebar_layout', 'right_sidebar' ) == 'left_sidebar' ) {
			get_sidebar();
		}

		if ( get_theme_mod( 'rdcode_page_sidebar_layout', 'right_sidebar' ) == 'no_sidebar' ) {
			$col_class = 'col-lg-12';
		} else {
			$col_class = 'col-lg-8';
		}
			?>
				<main class="<?php echo esc_attr( $col_class ); ?> col-sm-12 blog_container">
	    			<?php
	                    while ( have_posts() ) : the_post();
	                        
	                        get_template_part( 'template-parts/content', 'page' );

	                        if ( get_theme_mod( 'rdcode_single_page_comments', 'show' ) == 'show' ) {
		                        // If comments are open or we have at least one comment, load up the comment template.
								if ( comments_open() || get_comments_number() ) :
									comments_template();
								endif;
							}

	                    endwhile; // End of the loop.
	                ?>
	        	</main>
			<?php
		if ( get_theme_mod( 'rdcode_page_sidebar_layout', 'right_sidebar' ) == 'right_sidebar' ) {
			get_sidebar();
		}
	}

endif;

/*-----------------------------------------------------------------------------------------------------------------------*/

/**
 * Post side bar layout.
 *
 */
if( ! function_exists( 'rdcode_blog_sidebar_layout' ) ) :

	function rdcode_blog_sidebar_layout() {

		if ( get_theme_mod( 'rdcode_blog_sidebar_layout', 'right_sidebar' ) == 'left_sidebar' ) {
			get_sidebar();
		}

		if ( get_theme_mod( 'rdcode_blog_sidebar_layout', 'right_sidebar' ) == 'no_sidebar' ) {
			$col_class = 'col-lg-12';
		} else {
			$col_class = 'col-lg-8';
		}
			?>
				<div class="<?php echo esc_attr( $col_class ); ?> col-sm-6 blog_container">
					<?php
						if ( get_theme_mod( 'rdcode_archive_title_layout', 'above' ) == 'below' && get_theme_mod( 'rdcode_show_archive_title', 'show' ) == 'show' ) {
							the_archive_title( '<h2 class="font-tertiary mb-4">', '</h2>' );
						}
					?>
	        		<div class="row">
	                    <?php
	                    if ( have_posts() ) :

	                        /* Start the Loop */
	                        while ( have_posts() ) : the_post();
	                        
	                            get_template_part( 'template-parts/content', get_post_format() );

	                        endwhile;

	                    else :

	                        get_template_part( 'template-parts/content', 'none' );

	                    endif; ?>
	                </div>
	                <?php do_action( 'rdcode_post_pagination' ); ?>
	        	</div>
			<?php
		if ( get_theme_mod( 'rdcode_blog_sidebar_layout', 'right_sidebar' ) == 'right_sidebar' ) {
			get_sidebar();
		} 
	}

endif;

/*-----------------------------------------------------------------------------------------------------------------------*/

/**
 * Single Post side bar layout.
 *
 */
if( ! function_exists( 'rdcode_single_sidebar_layout' ) ) :

	function rdcode_single_sidebar_layout() {

		if ( get_theme_mod( 'rdcode_single_sidebar_layout', 'right_sidebar' ) == 'left_sidebar' ) {
			get_sidebar();
		}

		if ( get_theme_mod( 'rdcode_single_sidebar_layout', 'right_sidebar' ) == 'no_sidebar' ) {
			$col_class = 'col-lg-12';
		} else {
			$col_class = 'col-lg-8';
		}
			?>
				<main class="<?php echo esc_attr( $col_class ); ?> col-sm-12 blog_container">
	            	<?php
	                  	while ( have_posts() ) :
	                      	the_post();

	                      	get_template_part( 'template-parts/content', 'single' );

	                      	/**
					        * rdcode_single_post_navigation hook
					        *
					        * @hooked - rdcode_custom_single_post_navigation - 40
					        *
					        */
					        do_action( 'rdcode_post_author_box' );
					        do_action( 'rdcode_single_post_navigation' );
					        do_action( 'rdcode_related_posts' );

					        if ( get_theme_mod( 'rdcode_single_post_comments', 'show' ) == 'show' ) {
		                      	// If comments are open or we have at least one comment, load up the comment template.
		                      	if ( comments_open() || get_comments_number() ) :
		                          	comments_template();
		                      	endif;
		                    }

	                  	endwhile; // End of the loop.
	              	?>
	          	</main>
			<?php
		if ( get_theme_mod( 'rdcode_single_sidebar_layout', 'right_sidebar' ) == 'right_sidebar' ) {
			get_sidebar();
		}
	}

endif;

/*-----------------------------------------------------------------------------------------------------------------------*/

/**
 * Meta Tags.
 *
 */
if( ! function_exists( 'rdcode_meta_tags_layout' ) ) :

	/**
	 * Fav icon
	 *
	 * @since 1.0.0
	 */
	function rdcode_meta_tags_layout() {
		$rdcode_show_author_name   = get_theme_mod( 'rdcode_show_author_name', 'show' );
		$rdcode_show_post_date     = get_theme_mod( 'rdcode_show_post_date', 'show' );
		$rdcode_show_comment_count = get_theme_mod( 'rdcode_show_comment_count', 'show' );

		if ( ( ! empty ( $rdcode_show_author_name ) && $rdcode_show_author_name == 'show' ) || ( ! empty ( $rdcode_show_post_date ) && $rdcode_show_post_date == 'show' ) || ( ! empty ( $rdcode_show_comment_count ) && $rdcode_show_comment_count == 'show' ) ) {
		?>
		<ul class="meta-tag">
			<?php if ( ! empty ( $rdcode_show_author_name ) && $rdcode_show_author_name == 'show' ) { ?>
	        <li><?php rdcode_posted_by() ?></li>
	    	<?php } if ( ! empty ( $rdcode_show_post_date ) && $rdcode_show_post_date == 'show' ) { ?>
	        <li><?php rdcode_posted_on(); ?></li>
	        <?php } if ( ! empty ( $rdcode_show_comment_count ) && $rdcode_show_comment_count == 'show' ) { ?>
	        <li><?php rdcode_comments_count(); ?></li>
	    	<?php } ?>
	    </ul>
	    <?php
		}
	}

endif;

/*-----------------------------------------------------------------------------------------------------------------------*/

/**
 * Single Post Meta Tags.
 *
 */
if( ! function_exists( 'rdcode_single_post_meta_tags_layout' ) ) :

	/**
	 * Fav icon
	 *
	 * @since 1.0.0
	 */
	function rdcode_single_post_meta_tags_layout() {
		$rdcode_single_post_author   = get_theme_mod( 'rdcode_single_post_author', 'show' );
		$rdcode_single_post_date     = get_theme_mod( 'rdcode_single_post_date', 'show' );
		$rdcode_single_post_comment_count = get_theme_mod( 'rdcode_single_post_comment_count', 'show' );

		if ( ( ! empty ( $rdcode_single_post_author ) && $rdcode_single_post_author == 'show' ) || ( ! empty ( $rdcode_single_post_date ) && $rdcode_single_post_date == 'show' ) || ( ! empty ( $rdcode_single_post_comment_count ) && $rdcode_single_post_comment_count == 'show' ) ) {
		?>
		<ul class="meta-tag">
			<?php if ( ! empty ( $rdcode_single_post_author ) && $rdcode_single_post_author == 'show' ) { ?>
	        <li><?php rdcode_posted_by() ?></li>
	    	<?php } if ( ! empty ( $rdcode_single_post_date ) && $rdcode_single_post_date == 'show' ) { ?>
	        <li><?php rdcode_posted_on(); ?></li>
	        <?php } if ( ! empty ( $rdcode_single_post_comment_count ) && $rdcode_single_post_comment_count == 'show' ) { ?>
	        <li><?php rdcode_comments_count(); ?></li>
	    	<?php } ?>
	    </ul>
	    <?php
		}
	}

endif;

/*-----------------------------------------------------------------------------------------------------------------------*/

/**
 * Custom Post Navigation.
 *
 */
if ( ! function_exists( 'rdcode_custom_single_post_navigation' ) ) :

	function rdcode_custom_single_post_navigation() {
		$pagination = get_theme_mod( 'rdcode_single_post_navigation', 'show' );
		
		if ( $pagination == 'show' ) {
			$next_post = get_next_post();
			$prev_post = get_previous_post();
				
			if ( ( ! empty ( $prev_post ) ) || ( ! empty ( $next_post ) ) )	{
			?>
				<!--Next Prev Posts-->
				<article class="post-navigation">
					<div class="row">
						<?php
							//Previous Post
							if ( ! empty( $prev_post ) ) :
								$prev_title     = strip_tags( str_replace('"', '', $prev_post->post_title ) );
								$prev_thumbnail = get_the_post_thumbnail_url( $prev_post->ID );
							?>  
							<div class="col-6">
								<div class="prev">
									<a class="prev-post-label" href="<?php echo esc_attr( esc_url( get_permalink( get_previous_post() ) ) ); ?>">
										<div class="prev-post-title">
											<span><i class="fas fa-angle-double-left"></i> <?php esc_html_e( 'Previous post','dcode' ) ?></span>
											<h4><?php echo esc_html( $prev_title ); ?></h4>
										</div>
										<?php if ( ! empty ( $prev_thumbnail ) ) { ?>
											<figure>
												<img width="160" height="160" src="<?php echo esc_url( $prev_thumbnail ); ?>" class="attachment-thumbnail size-thumbnail wp-post-image" alt="">
											</figure>	
										<?php } ?>
									</a>
								</div>
							</div>
						<?php
							endif;
							
							//Next Post
							if ( ! empty( $next_post ) ) :
								$next_title     = strip_tags( str_replace( '"', '', $next_post->post_title ) );
								$next_thumbnail = get_the_post_thumbnail_url( $next_post->ID );
						?>
							<div class="col-6 text-right">
								<div class="next">
									<a class="next-post-label" href="<?php echo esc_attr( esc_url( get_permalink( get_next_post() ) ) ); ?>">
										<div class="next-post-title">
											<span><?php esc_html_e( 'Next post','dcode' ) ?> <i class="fas fa-angle-double-right"></i></span>
											<h4><?php echo esc_html( $next_title ); ?></h4>
										</div>
										<?php if ( ! empty ( $next_thumbnail ) ) { ?>
											<figure>
												<img width="160" height="160" src="<?php echo esc_url( $next_thumbnail ); ?>" class="attachment-thumbnail size-thumbnail wp-post-image" alt="">
											</figure>
										<?php } ?>
									</a>
								</div>
							</div>
						<?php endif; ?>
					</div>
				</article>
				<!--/ Next Prev Posts-->
			<?php }
		}
	}

endif;

/*-----------------------------------------------------------------------------------------------------------------------*/

/**
 * Related Posts.
 *
 */
if ( ! function_exists( 'rdcode_single_post_related_posts' ) ) :

	function rdcode_single_post_related_posts() {
		if ( get_theme_mod( 'rdcode_single_related_posts', 'show' ) == 'show' ) {
			$related_col = get_theme_mod( 'rdcode_single_related_col', 'col-lg-6' );

			if ( $related_col == 'col-lg-6' ) {
				$count = 2;
			} elseif ( $related_col == 'col-lg-4' ) {
				$count = 3;
			} else {
				$count = 4;
			}
		?>
		<article class="related-posts">
			<h3>Related Posts</h3>
			<div class="row">
				<?php
	         		$args  = array(  
		  		        'post_type'      => 'post',
		  		        'post_status'    => 'publish',
		  		        'posts_per_page' => $count,
		  		        'category__in'   => wp_get_post_categories(get_the_ID()),
		  		        'post__not_in'   => array( get_the_ID() )
	  			    );

			      	$loop = new WP_Query( $args );
						while ( $loop->have_posts() ) : $loop->the_post();
		       	?>
				<div class="<?php echo esc_attr($related_col); ?> col-md-6 mb-4 mb-lg-0 d-grid-item">
		            <article class=" card shadow hover-shadow blog-item wow fadeInUp">
		                <figure>
		            		<?php 
		            			if ( has_post_thumbnail() ) {
		  					        echo '<a href="'.esc_attr( esc_url( get_the_permalink() ) ).'" rel="lightbox">'; 
		  					            the_post_thumbnail( 'rdcode-blog-thumb', array( 'class' => 'blog-img rounded card-img-top' ) );
		  					        echo '</a>';
		  				        }
		            		?>
			               	<figcaption class="card-body">
			                  	<header class="card-title entry-header">
				                    <h3 class="entry-title">
				                  		<a href="<?php echo esc_attr( esc_url( get_the_permalink() ) ); ?>"><?php the_title(); ?></a>
				                    </h3>
			                  	</header>
			                    <?php 
			                    /**
			                     * rdcode_meta_tags hook
			                     *
			                     * @hooked - rdcode_meta_tags_layout - 35
			                     *
			                     * @since 1.0.0
			                     */
			                    do_action( 'rdcode_meta_tags' ); ?>

			                  	<p class="cars-text"><?php the_excerpt(); ?></p>
			                  	<a href="<?php echo esc_attr( esc_url( get_the_permalink() ) ); ?>" class="btn btn-xs btn-primary">
			                  		<?php echo esc_html( get_theme_mod( 'rdcode_archive_read_more_text', 'Read More' ) ); ?>
			                  	</a>
			               	</figcaption>
		                 </figure>
		            </article>
		        </div>
		        <?php endwhile; wp_reset_postdata(); ?>
			</div>
		</article>
		<?php
		}
	}

endif;

/*-----------------------------------------------------------------------------------------------------------------------*/

/**
 * Post author box
 *
 */
if ( ! function_exists( 'rdcode_single_post_author_box' ) ) :

	function rdcode_single_post_author_box() {
		$author_box = get_theme_mod( 'rdcode_single_post_author_box', 'show' );
		if ( $author_box == 'show' ) {
			global $post;
			$author_id        = $post->post_author;
			$user_description = get_the_author_meta( 'user_description', $author_id );

			// Get author's display name 
			$display_name = get_the_author_meta( 'display_name', $author_id );
  
			// If display name is not available then use nickname as display name
			if ( empty( $display_name ) )
			$display_name = get_the_author_meta( 'nickname', $author_id );

			// Get author's website URL 
			$user_website = get_the_author_meta( 'url', $author_id );
			  
			// Get link to the author archive page
			$user_posts   = get_author_posts_url( get_the_author_meta( 'ID' , $author_id ) );
			$avatar       = get_avatar( get_the_author_meta('ID') )
			?>
			<article class="post-author-box">
				<div class="row">
					<div class="col-lg-2 col-md-6 mb-4 mb-lg-0 d-grid-item">
						<?php if(!empty($avatar)) { echo wp_kses_post( $avatar ); } ?>
					</div>
					<div class="col-lg-10 col-md-6 mb-4 mb-lg-0 d-grid-item">
						<a href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>">
							<h4><?php echo esc_html( $display_name ); ?></h4>
						</a>
						<p><?php echo esc_html( $user_description ); ?></p>
						<p class="author_links">
							<a href="<?php echo esc_url( $user_posts ); ?>"><?php echo esc_html__( 'View all posts by', 'dcode' ).' '.$display_name; ?></a> | <a href="<?php echo esc_url( $user_website ); ?>" target="_blank" rel="nofollow"><?php esc_html_e( 'Website', 'dcode' ); ?></a>
						</p>
					</div>
				</div>
			</article>
			<?php
		}
	}

endif;

/*-----------------------------------------------------------------------------------------------------------------------*/

/**
 * Managed functions for Custom Hooks
 *
 * @since 1.0.0
 */
add_action( 'rdcode_preloader', 'rdcode_preloader', 5 );
add_action( 'rdcode_readmore', 'rdcode_readmore_txt', 10 );
add_action( 'rdcode_post_pagination', 'rdcode_post_pagination_call', 15 );
add_action( 'rdcode_page_layout', 'rdcode_page_sidebar_layout', 20 );
add_action( 'rdcode_post_layout', 'rdcode_blog_sidebar_layout', 25 );
add_action( 'rdcode_single_layout', 'rdcode_single_sidebar_layout', 30 );
add_action( 'rdcode_meta_tags', 'rdcode_meta_tags_layout', 35 );
add_action( 'rdcode_single_post_navigation', 'rdcode_custom_single_post_navigation', 40 );
add_action( 'rdcode_related_posts', 'rdcode_single_post_related_posts', 45 );
add_action( 'rdcode_post_author_box', 'rdcode_single_post_author_box', 50 );
add_action( 'rdcode_single_meta_tags', 'rdcode_single_post_meta_tags_layout', 55 );