<?php
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Dcode
 * @since 1.0
*/

/*---------------------------------------------------------------------------------------------------------------------------------*/

if ( ! function_exists( 'rdcode_post_thumbnail' ) ) :
	/**
	 * Displays an optional post thumbnail.
	 *
	 * Wraps the post thumbnail in an anchor element on index views, or a div
	 * element when on single views.
	 */
	function rdcode_post_thumbnail() {
		if ( post_password_required() || is_attachment() || ! has_post_thumbnail() ) {
			return;
		}

		if ( is_singular() ) :
			?>
        <div class="img-wapper">
            <?php the_post_thumbnail( 'full', array( 
                'alt' => the_title_attribute( 
                            array(
                            	'echo' => false,
                            ) 
                        ),
                'class' => 'img-fluid'
            ) 
        ); ?>
        </div>
        <?php else : ?>

        <div class="img-wapper">
            <a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true" tabindex="-1">
                <?php
				the_post_thumbnail( 'post-thumbnail', 
					array(
						'alt' => the_title_attribute( 
							array(
								'echo' => false,
							) 
						),
						'class' => 'img-fluid',
					) 
				);
                ?>
            </a>
        </div>

		<?php
		endif; // End is_singular().
	}
endif;

/*---------------------------------------------------------------------------------------------------------------------------------*/

if ( ! function_exists( 'rdcode_posted_on' ) ) :
	/**
	 * Prints HTML with meta information for the current post-date/time.
	 */
	function rdcode_posted_on() {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time>';
		}

		$time_string = sprintf( $time_string,
			esc_attr( get_the_date( DATE_W3C ) ),
			esc_html( get_the_date() )
		);

		$posted_on = '<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">  <time class="entry-date"><i class="far fa-calendar-alt"></i> ' . $time_string . ' </time> </a>';

		/* translators: 1: Post publish date. */
		printf( '%1$s', wp_kses_post( $posted_on ) );

	}
endif;

/*---------------------------------------------------------------------------------------------------------------------------------*/

if ( ! function_exists( 'rdcode_posted_by' ) ) :
	/**
	 * Prints HTML with meta information for the current author.
	 */
	function rdcode_posted_by() {
		$byline = '<a href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '"><i class="fa fa-user"></i> ' . esc_html( get_the_author() ) . '</a>';

		/* translators: 1: Author name. */
		printf( '%1$s', wp_kses_post( $byline ) );

	}
endif;

/*---------------------------------------------------------------------------------------------------------------------------------*/

if ( ! function_exists( 'rdcode_comments_count' ) ) :
	/**
	 * Prints HTML with meta information for the current author.
	 */
	function rdcode_comments_count() {
		$count = '<a href="'.get_the_permalink().'#respond"><i class="fa fa-comments"></i> ' . esc_html( get_comments_number() ) . '</a>';

		/* translators: 1: Comments count. */
		printf( '%1$s', wp_kses_post( $count ) );

	}
endif;

/*---------------------------------------------------------------------------------------------------------------------------------*/

if ( ! function_exists( 'rdcode_entry_taxonomy' ) ) :
	/**
	 * Prints HTML with meta information for the categories, tags and comments.
	 */
	function rdcode_entry_taxonomy() {
		// Hide category and tag text for pages.
		if ( 'post' === get_post_type() ) {

			if ( get_theme_mod( 'rdcode_single_post_tags', 'show' ) == 'show' ) {

				/* translators: used between list items, there is a space after the comma */
				$categories_list = get_the_category_list( esc_html__( ', ', 'dcode' ) );
				if ( $categories_list ) {
					/* translators: 1: list of categories. */
					printf( '<span class="cat-links"><i class="fas fa-tags"></i><span class="meta-title">' . esc_html__( 'Posted in ', 'dcode' ) . '</span>%1$s</span>', wp_kses_post( $categories_list ) );
				}
			}

			if ( get_theme_mod( 'rdcode_single_post_categories', 'show' ) == 'show' ) {

				/* translators: used between list items, there is a space after the comma */
				$tags_list = get_the_tag_list( '', esc_html_x( ', ', 'list item separator', 'dcode' ) );
				if ( $tags_list ) {
					/* translators: 1: list of tags. */
					printf( '<span class="tags-links"><i class="fas fa-tags"></i><span class="meta-title">' . esc_html__( 'Tagged in ', 'dcode' ) . '</span>%1$s</span>', wp_kses_post( $tags_list ) );
				}
			}
			
		}

		if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
			echo '<span class="comments-link">';
			comments_popup_link(
				sprintf(
					wp_kses(
						/* translators: %s: post title */
						__( 'Leave a Comment<span class="screen-reader-text"> on %s</span>', 'dcode' ),
						array(
							'span' => array(
								'class' => array(),
							),
						)
					),
					get_the_title()
				)
			);
			echo '</span>';
		}

		edit_post_link(
			sprintf(
				wp_kses(
					/* translators: %s: Name of current post. Only visible to screen readers */
					__( 'Edit <span class="screen-reader-text">%s</span>', 'dcode' ),
					array(
						'span' => array(
							'class' => array(),
						),
					)
				),
				get_the_title()
			),
			'<span class="edit-link">',
			'</span>'
		);
	}
endif;

/*---------------------------------------------------------------------------------------------------------------------------------*/

if( ! function_exists( 'rdcode_font_awesome_social_icon_array' ) ) :

    /**
     * Define font awesome social media icons
     *
     * @return array();
     * @since 1.0.0
     */

    function rdcode_font_awesome_social_icon_array(){
        return array(
            "fab fa-facebook-square","fab fa-facebook-f","fab fa-facebook","fab fa-facebook-messenger","fab fa-twitter-square","fab fa-twitter","fab fa-yahoo","fab fa-google","fab fa-google-wallet","fab fa-google-plus","fab fa-google-plus-g","fab fa-google-plus-square","fab fa-instagram","fab fa-linkedin-in","fab fa-linkedin","fab fa-pinterest-p","fab fa-pinterest","fab fa-pinterest-square","fab fa-google-plus-square","fab fa-google-plus","fab fa-youtube-square","fab fa-youtube","fab fa-vimeo","fab fa-vimeo-square","fab fa-behance","fab fa-behance-square", "fab fa-facebook", "fas fa-thumbs-up", "far fa-thumbs-up", "fas fa-thumbs-down", "far fa-thumbs-down", "fas fa-video", "fas fa-users", "fas fa-user-friends", "fas fa-user-circle", "far fa-user-circle", "fas fa-star", "far fa-star", "fas fa-camera", "fas fa-birthday-cake", "fas fa-bell", "far fa-bell", "fas fa-comment", "far fa-comment", "fas fa-heart", "far fa-heart", "fas fa-poll", "fas fa-map-marker-alt", "fab fa-accessible-icon", "fas fa-ad", "fas fa-address-book", "far fa-address-book", "fas fa-address-card", "far fa-address-card", "fas fa-adjust", "fas fa-air-freshener", "fab fa-algolia", "fas fa-align-center", "fas fa-align-justify", "fas fa-align-left", "fas fa-align-right", "fab fa-alipay", "fab fa-amazon", "fab fa-amazon-pay", "fas fa-ambulance", "fas fa-american-sign-language-interpreting", "fas fa-anchor", "fab fa-android", "fab fa-angellist", "fas fa-angle-double-down", "fas fa-angle-double-left", "fas fa-angle-double-right", "fas fa-angle-double-up", "fas fa-angle-down", "fas fa-angle-left", "fas fa-angle-right", "fas fa-angle-up", "fas fa-angry", "far fa-angry", "fab fa-angrycreative", "fab fa-angular", "fas fa-ankh", "fab fa-app-store", "fab fa-app-store-ios", "fab fa-apper", "fab fa-apple", "fas fa-apple-alt", "fab fa-apple-pay", "fas fa-archive", "fas fa-archway", "fas fa-arrow-alt-circle-down", "far fa-arrow-alt-circle-down", "fas fa-arrow-alt-circle-left", "far fa-arrow-alt-circle-left", "fas fa-arrow-alt-circle-right", "far fa-arrow-alt-circle-right", "fas fa-arrow-alt-circle-up", "far fa-arrow-alt-circle-up", "fas fa-arrow-circle-down", "fas fa-arrow-circle-left", "fas fa-arrow-circle-right", "fas fa-arrow-circle-up", "fas fa-arrow-down", "fas fa-arrow-left", "fas fa-arrow-right", "fas fa-arrow-up", "fas fa-atlas", "fas fa-atom", "fas fa-award", "fab fa-aws", "fas fa-backspace", "fas fa-backward", "fas fa-balance-scale", "fas fa-band-aid", "fas fa-ban", "fas fa-bars", "fas fa-baseball-ball", "fas fa-basketball-ball", "fas fa-bath", "fas fa-battery-empty", "fas fa-battery-full", "fas fa-battery-half", "fas fa-bed", "fas fa-beer", "fab fa-behance", "fab fa-behance-square", "fas fa-bell", "far fa-bell", "fas fa-bell-slash", "far fa-bell-slash", "fas fa-bible", "fas fa-bicycle", "fas fa-binoculars", "fas fa-birthday-cake", "fab fa-bitcoin", "fab fa-blogger", "fas fa-bomb", "fas fa-book", "fas fa-book-open", "fas fa-bookmark", "far fa-bookmark", "fas fa-bowling-ball", "fas fa-briefcase", "fas fa-briefcase-medical", "fas fa-brush", "fas fa-bug", "fas fa-building", "fas fa-bullhorn", "fas fa-bullseye", "fas fa-burn", "fas fa-bus", "fas fa-bus-alt", "fas fa-business-time", "fas fa-calculator", "fas fa-calendar", "far fa-calendar", "fas fa-calendar-alt", "far fa-calendar-alt", "far fa-calendar-check", "fas fa-calendar-plus", "fas fa-calendar-times", "fas fa-camera", "fas fa-camera-retro", "fas fa-cannabis", "fas fa-capsules", "fas fa-car", "fas fa-car-battery", "fas fa-cart-plus", "fas fa-chart-area", "fas fa-chart-bar", "fas fa-chart-line", "fas fa-chart-pie", "far fa-check-circle", "fas fa-check-circle", "fas fa-chess", "fas fa-code"
        );
    }
    
endif;

/*---------------------------------------------------------------------------------------------------------------------------------*/

if ( ! function_exists( 'rdcode_get_google_fonts' ) ) :
	
	/**
	 * List of All Google fonts
	 *
	 * @since 1.1.38
	 */
	function rdcode_get_google_fonts() {
		return apply_filters(
			'rdcode_google_fonts_array',
			array(
				'ABeeZee',
				'Abel',
				'Abhaya Libre',
				'Abril Fatface',
				'Aclonica',
				'Acme',
				'Actor',
				'Adamina',
				'Advent Pro',
				'Aguafina Script',
				'Akronim',
				'Aladin',
				'Aldrich',
				'Alef',
				'Alegreya',
				'Alegreya SC',
				'Alegreya Sans',
				'Alegreya Sans SC',
				'Aleo',
				'Alex Brush',
				'Alfa Slab One',
				'Alice',
				'Alike',
				'Alike Angular',
				'Allan',
				'Allerta',
				'Allerta Stencil',
				'Allura',
				'Almendra',
				'Almendra Display',
				'Almendra SC',
				'Amarante',
				'Amaranth',
				'Amatic SC',
				'Amethysta',
				'Amiko',
				'Amiri',
				'Amita',
				'Anaheim',
				'Andada',
				'Andika',
				'Angkor',
				'Annie Use Your Telescope',
				'Anonymous Pro',
				'Antic',
				'Antic Didone',
				'Antic Slab',
				'Anton',
				'Arapey',
				'Arbutus',
				'Arbutus Slab',
				'Architects Daughter',
				'Archivo',
				'Archivo Black',
				'Archivo Narrow',
				'Aref Ruqaa',
				'Arima Madurai',
				'Arimo',
				'Arizonia',
				'Armata',
				'Arsenal',
				'Artifika',
				'Arvo',
				'Arya',
				'Asap',
				'Asap Condensed',
				'Asar',
				'Asset',
				'Assistant',
				'Astloch',
				'Asul',
				'Athiti',
				'Atma',
				'Atomic Age',
				'Aubrey',
				'Audiowide',
				'Autour One',
				'Average',
				'Average Sans',
				'Averia Gruesa Libre',
				'Averia Libre',
				'Averia Sans Libre',
				'Averia Serif Libre',
				'B612',
				'B612 Mono',
				'Bad Script',
				'Bahiana',
				'Bahianita',
				'Bai Jamjuree',
				'Baloo',
				'Baloo Bhai',
				'Baloo Bhaijaan',
				'Baloo Bhaina',
				'Baloo Chettan',
				'Baloo Da',
				'Baloo Paaji',
				'Baloo Tamma',
				'Baloo Tammudu',
				'Baloo Thambi',
				'Balthazar',
				'Bangers',
				'Barlow',
				'Barlow Condensed',
				'Barlow Semi Condensed',
				'Barriecito',
				'Barrio',
				'Basic',
				'Battambang',
				'Baumans',
				'Bayon',
				'Belgrano',
				'Bellefair',
				'Belleza',
				'BenchNine',
				'Bentham',
				'Berkshire Swash',
				'Bevan',
				'Bigelow Rules',
				'Bigshot One',
				'Bilbo',
				'Bilbo Swash Caps',
				'BioRhyme',
				'BioRhyme Expanded',
				'Biryani',
				'Bitter',
				'Black And White Picture',
				'Black Han Sans',
				'Black Ops One',
				'Bokor',
				'Bonbon',
				'Boogaloo',
				'Bowlby One',
				'Bowlby One SC',
				'Brawler',
				'Bree Serif',
				'Bubblegum Sans',
				'Bubbler One',
				'Buda',
				'Buenard',
				'Bungee',
				'Bungee Hairline',
				'Bungee Inline',
				'Bungee Outline',
				'Bungee Shade',
				'Butcherman',
				'Butterfly Kids',
				'Cabin',
				'Cabin Condensed',
				'Cabin Sketch',
				'Caesar Dressing',
				'Cagliostro',
				'Cairo',
				'Calligraffitti',
				'Cambay',
				'Cambo',
				'Candal',
				'Cantarell',
				'Cantata One',
				'Cantora One',
				'Capriola',
				'Cardo',
				'Carme',
				'Carrois Gothic',
				'Carrois Gothic SC',
				'Carter One',
				'Catamaran',
				'Caudex',
				'Caveat',
				'Caveat Brush',
				'Cedarville Cursive',
				'Ceviche One',
				'Chakra Petch',
				'Changa',
				'Changa One',
				'Chango',
				'Charm',
				'Charmonman',
				'Chathura',
				'Chau Philomene One',
				'Chela One',
				'Chelsea Market',
				'Chenla',
				'Cherry Cream Soda',
				'Cherry Swash',
				'Chewy',
				'Chicle',
				'Chivo',
				'Chonburi',
				'Cinzel',
				'Cinzel Decorative',
				'Clicker Script',
				'Coda',
				'Coda Caption',
				'Codystar',
				'Coiny',
				'Combo',
				'Comfortaa',
				'Coming Soon',
				'Concert One',
				'Condiment',
				'Content',
				'Contrail One',
				'Convergence',
				'Cookie',
				'Copse',
				'Corben',
				'Cormorant',
				'Cormorant Garamond',
				'Cormorant Infant',
				'Cormorant SC',
				'Cormorant Unicase',
				'Cormorant Upright',
				'Courgette',
				'Cousine',
				'Coustard',
				'Covered By Your Grace',
				'Crafty Girls',
				'Creepster',
				'Crete Round',
				'Crimson Text',
				'Croissant One',
				'Crushed',
				'Cuprum',
				'Cute Font',
				'Cutive',
				'Cutive Mono',
				'DM Sans',
				'DM Serif Display',
				'DM Serif Text',
				'Damion',
				'Dancing Script',
				'Dangrek',
				'Darker Grotesque',
				'David Libre',
				'Dawning of a New Day',
				'Days One',
				'Dekko',
				'Delius',
				'Delius Swash Caps',
				'Delius Unicase',
				'Della Respira',
				'Denk One',
				'Devonshire',
				'Dhurjati',
				'Didact Gothic',
				'Diplomata',
				'Diplomata SC',
				'Do Hyeon',
				'Dokdo',
				'Domine',
				'Donegal One',
				'Doppio One',
				'Dorsa',
				'Dosis',
				'Dr Sugiyama',
				'Duru Sans',
				'Dynalight',
				'EB Garamond',
				'Eagle Lake',
				'East Sea Dokdo',
				'Eater',
				'Economica',
				'Eczar',
				'El Messiri',
				'Electrolize',
				'Elsie',
				'Elsie Swash Caps',
				'Emblema One',
				'Emilys Candy',
				'Encode Sans',
				'Encode Sans Condensed',
				'Encode Sans Expanded',
				'Encode Sans Semi Condensed',
				'Encode Sans Semi Expanded',
				'Engagement',
				'Englebert',
				'Enriqueta',
				'Erica One',
				'Esteban',
				'Euphoria Script',
				'Ewert',
				'Exo',
				'Exo 2',
				'Expletus Sans',
				'Fahkwang',
				'Fanwood Text',
				'Farsan',
				'Fascinate',
				'Fascinate Inline',
				'Faster One',
				'Fasthand',
				'Fauna One',
				'Faustina',
				'Federant',
				'Federo',
				'Felipa',
				'Fenix',
				'Finger Paint',
				'Fira Mono',
				'Fira Sans',
				'Fira Sans Condensed',
				'Fira Sans Extra Condensed',
				'Fjalla One',
				'Fjord One',
				'Flamenco',
				'Flavors',
				'Fondamento',
				'Fontdiner Swanky',
				'Forum',
				'Francois One',
				'Frank Ruhl Libre',
				'Freckle Face',
				'Fredericka the Great',
				'Fredoka One',
				'Freehand',
				'Fresca',
				'Frijole',
				'Fruktur',
				'Fugaz One',
				'GFS Didot',
				'GFS Neohellenic',
				'Gabriela',
				'Gaegu',
				'Gafata',
				'Galada',
				'Galdeano',
				'Galindo',
				'Gamja Flower',
				'Gentium Basic',
				'Gentium Book Basic',
				'Geo',
				'Geostar',
				'Geostar Fill',
				'Germania One',
				'Gidugu',
				'Gilda Display',
				'Give You Glory',
				'Glass Antiqua',
				'Glegoo',
				'Gloria Hallelujah',
				'Goblin One',
				'Gochi Hand',
				'Gorditas',
				'Gothic A1',
				'Goudy Bookletter 1911',
				'Graduate',
				'Grand Hotel',
				'Gravitas One',
				'Great Vibes',
				'Griffy',
				'Gruppo',
				'Gudea',
				'Gugi',
				'Gurajada',
				'Habibi',
				'Halant',
				'Hammersmith One',
				'Hanalei',
				'Hanalei Fill',
				'Handlee',
				'Hanuman',
				'Happy Monkey',
				'Harmattan',
				'Headland One',
				'Heebo',
				'Henny Penny',
				'Herr Von Muellerhoff',
				'Hi Melody',
				'Hind',
				'Hind Guntur',
				'Hind Madurai',
				'Hind Siliguri',
				'Hind Vadodara',
				'Holtwood One SC',
				'Homemade Apple',
				'Homenaje',
				'IBM Plex Mono',
				'IBM Plex Sans',
				'IBM Plex Sans Condensed',
				'IBM Plex Serif',
				'IM Fell DW Pica',
				'IM Fell DW Pica SC',
				'IM Fell Double Pica',
				'IM Fell Double Pica SC',
				'IM Fell English',
				'IM Fell English SC',
				'IM Fell French Canon',
				'IM Fell French Canon SC',
				'IM Fell Great Primer',
				'IM Fell Great Primer SC',
				'Iceberg',
				'Iceland',
				'Imprima',
				'Inconsolata',
				'Inder',
				'Indie Flower',
				'Inika',
				'Inknut Antiqua',
				'Irish Grover',
				'Istok Web',
				'Italiana',
				'Italianno',
				'Itim',
				'Jacques Francois',
				'Jacques Francois Shadow',
				'Jaldi',
				'Jim Nightshade',
				'Jockey One',
				'Jolly Lodger',
				'Jomhuria',
				'Josefin Sans',
				'Josefin Slab',
				'Joti One',
				'Jua',
				'Judson',
				'Julee',
				'Julius Sans One',
				'Junge',
				'Jura',
				'Just Another Hand',
				'Just Me Again Down Here',
				'K2D',
				'Kadwa',
				'Kalam',
				'Kameron',
				'Kanit',
				'Kantumruy',
				'Karla',
				'Karma',
				'Katibeh',
				'Kaushan Script',
				'Kavivanar',
				'Kavoon',
				'Kdam Thmor',
				'Keania One',
				'Kelly Slab',
				'Kenia',
				'Khand',
				'Khmer',
				'Khula',
				'Kirang Haerang',
				'Kite One',
				'Knewave',
				'KoHo',
				'Kodchasan',
				'Kosugi',
				'Kosugi Maru',
				'Kotta One',
				'Koulen',
				'Kranky',
				'Kreon',
				'Kristi',
				'Krona One',
				'Krub',
				'Kumar One',
				'Kumar One Outline',
				'Kurale',
				'La Belle Aurore',
				'Laila',
				'Lakki Reddy',
				'Lalezar',
				'Lancelot',
				'Lateef',
				'Lato',
				'League Script',
				'Leckerli One',
				'Ledger',
				'Lekton',
				'Lemon',
				'Lemonada',
				'Libre Barcode 128',
				'Libre Barcode 128 Text',
				'Libre Barcode 39',
				'Libre Barcode 39 Extended',
				'Libre Barcode 39 Extended Text',
				'Libre Barcode 39 Text',
				'Libre Baskerville',
				'Libre Franklin',
				'Life Savers',
				'Lilita One',
				'Lily Script One',
				'Limelight',
				'Linden Hill',
				'Literata',
				'Lobster',
				'Lobster Two',
				'Londrina Outline',
				'Londrina Shadow',
				'Londrina Sketch',
				'Londrina Solid',
				'Lora',
				'Love Ya Like A Sister',
				'Loved by the King',
				'Lovers Quarrel',
				'Luckiest Guy',
				'Lusitana',
				'Lustria',
				'M PLUS 1p',
				'M PLUS Rounded 1c',
				'Macondo',
				'Macondo Swash Caps',
				'Mada',
				'Magra',
				'Maiden Orange',
				'Maitree',
				'Major Mono Display',
				'Mako',
				'Mali',
				'Mallanna',
				'Mandali',
				'Manuale',
				'Marcellus',
				'Marcellus SC',
				'Marck Script',
				'Margarine',
				'Markazi Text',
				'Marko One',
				'Marmelad',
				'Martel',
				'Martel Sans',
				'Marvel',
				'Mate',
				'Mate SC',
				'Maven Pro',
				'McLaren',
				'Meddon',
				'MedievalSharp',
				'Medula One',
				'Meera Inimai',
				'Megrim',
				'Meie Script',
				'Merienda',
				'Merienda One',
				'Merriweather',
				'Merriweather Sans',
				'Metal',
				'Metal Mania',
				'Metamorphous',
				'Metrophobic',
				'Michroma',
				'Milonga',
				'Miltonian',
				'Miltonian Tattoo',
				'Mina',
				'Miniver',
				'Miriam Libre',
				'Mirza',
				'Miss Fajardose',
				'Mitr',
				'Modak',
				'Modern Antiqua',
				'Mogra',
				'Molengo',
				'Molle',
				'Monda',
				'Monofett',
				'Monoton',
				'Monsieur La Doulaise',
				'Montaga',
				'Montez',
				'Montserrat',
				'Montserrat Alternates',
				'Montserrat Subrayada',
				'Moul',
				'Moulpali',
				'Mountains of Christmas',
				'Mouse Memoirs',
				'Mr Bedfort',
				'Mr Dafoe',
				'Mr De Haviland',
				'Mrs Saint Delafield',
				'Mrs Sheppards',
				'Mukta',
				'Mukta Mahee',
				'Mukta Malar',
				'Mukta Vaani',
				'Muli',
				'Mystery Quest',
				'NTR',
				'Nanum Brush Script',
				'Nanum Gothic',
				'Nanum Gothic Coding',
				'Nanum Myeongjo',
				'Nanum Pen Script',
				'Neucha',
				'Neuton',
				'New Rocker',
				'News Cycle',
				'Niconne',
				'Niramit',
				'Nixie One',
				'Nobile',
				'Nokora',
				'Norican',
				'Nosifer',
				'Notable',
				'Nothing You Could Do',
				'Noticia Text',
				'Noto Sans',
				'Noto Sans HK',
				'Noto Sans JP',
				'Noto Sans KR',
				'Noto Sans SC',
				'Noto Sans TC',
				'Noto Serif',
				'Noto Serif JP',
				'Noto Serif KR',
				'Noto Serif SC',
				'Noto Serif TC',
				'Nova Cut',
				'Nova Flat',
				'Nova Mono',
				'Nova Oval',
				'Nova Round',
				'Nova Script',
				'Nova Slim',
				'Nova Square',
				'Numans',
				'Nunito',
				'Nunito Sans',
				'Odor Mean Chey',
				'Offside',
				'Old Standard TT',
				'Oldenburg',
				'Oleo Script',
				'Oleo Script Swash Caps',
				'Open Sans',
				'Open Sans Condensed',
				'Oranienbaum',
				'Orbitron',
				'Oregano',
				'Orienta',
				'Original Surfer',
				'Oswald',
				'Over the Rainbow',
				'Overlock',
				'Overlock SC',
				'Overpass',
				'Overpass Mono',
				'Ovo',
				'Oxygen',
				'Oxygen Mono',
				'PT Mono',
				'PT Sans',
				'PT Sans Caption',
				'PT Sans Narrow',
				'PT Serif',
				'PT Serif Caption',
				'Pacifico',
				'Padauk',
				'Palanquin',
				'Palanquin Dark',
				'Pangolin',
				'Paprika',
				'Parisienne',
				'Passero One',
				'Passion One',
				'Pathway Gothic One',
				'Patrick Hand',
				'Patrick Hand SC',
				'Pattaya',
				'Patua One',
				'Pavanam',
				'Paytone One',
				'Peddana',
				'Peralta',
				'Permanent Marker',
				'Petit Formal Script',
				'Petrona',
				'Philosopher',
				'Piedra',
				'Pinyon Script',
				'Pirata One',
				'Plaster',
				'Play',
				'Playball',
				'Playfair Display',
				'Playfair Display SC',
				'Podkova',
				'Poiret One',
				'Poller One',
				'Poly',
				'Pompiere',
				'Pontano Sans',
				'Poor Story',
				'Poppins',
				'Port Lligat Sans',
				'Port Lligat Slab',
				'Pragati Narrow',
				'Prata',
				'Preahvihear',
				'Press Start 2P',
				'Pridi',
				'Princess Sofia',
				'Prociono',
				'Prompt',
				'Prosto One',
				'Proza Libre',
				'Puritan',
				'Purple Purse',
				'Quando',
				'Quantico',
				'Quattrocento',
				'Quattrocento Sans',
				'Questrial',
				'Quicksand',
				'Quintessential',
				'Qwigley',
				'Racing Sans One',
				'Radley',
				'Rajdhani',
				'Rakkas',
				'Raleway',
				'Raleway Dots',
				'Ramabhadra',
				'Ramaraja',
				'Rambla',
				'Rammetto One',
				'Ranchers',
				'Rancho',
				'Ranga',
				'Rasa',
				'Rationale',
				'Ravi Prakash',
				'Redressed',
				'Reem Kufi',
				'Reenie Beanie',
				'Revalia',
				'Rhodium Libre',
				'Ribeye',
				'Ribeye Marrow',
				'Righteous',
				'Risque',
				'Roboto',
				'Roboto Condensed',
				'Roboto Mono',
				'Roboto Slab',
				'Rochester',
				'Rock Salt',
				'Rokkitt',
				'Romanesco',
				'Ropa Sans',
				'Rosario',
				'Rosarivo',
				'Rouge Script',
				'Rozha One',
				'Rubik',
				'Rubik Mono One',
				'Ruda',
				'Rufina',
				'Ruge Boogie',
				'Ruluko',
				'Rum Raisin',
				'Ruslan Display',
				'Russo One',
				'Ruthie',
				'Rye',
				'Sacramento',
				'Sahitya',
				'Sail',
				'Saira',
				'Saira Condensed',
				'Saira Extra Condensed',
				'Saira Semi Condensed',
				'Salsa',
				'Sanchez',
				'Sancreek',
				'Sansita',
				'Sarabun',
				'Sarala',
				'Sarina',
				'Sarpanch',
				'Satisfy',
				'Sawarabi Gothic',
				'Sawarabi Mincho',
				'Scada',
				'Scheherazade',
				'Schoolbell',
				'Scope One',
				'Seaweed Script',
				'Secular One',
				'Sedgwick Ave',
				'Sedgwick Ave Display',
				'Sevillana',
				'Seymour One',
				'Shadows Into Light',
				'Shadows Into Light Two',
				'Shanti',
				'Share',
				'Share Tech',
				'Share Tech Mono',
				'Shojumaru',
				'Short Stack',
				'Shrikhand',
				'Siemreap',
				'Sigmar One',
				'Signika',
				'Signika Negative',
				'Simonetta',
				'Sintony',
				'Sirin Stencil',
				'Six Caps',
				'Skranji',
				'Slabo 13px',
				'Slabo 27px',
				'Slackey',
				'Smokum',
				'Smythe',
				'Sniglet',
				'Snippet',
				'Snowburst One',
				'Sofadi One',
				'Sofia',
				'Song Myung',
				'Sonsie One',
				'Sorts Mill Goudy',
				'Source Code Pro',
				'Source Sans Pro',
				'Source Serif Pro',
				'Space Mono',
				'Special Elite',
				'Spectral',
				'Spectral SC',
				'Spicy Rice',
				'Spinnaker',
				'Spirax',
				'Squada One',
				'Sree Krushnadevaraya',
				'Sriracha',
				'Srisakdi',
				'Staatliches',
				'Stalemate',
				'Stalinist One',
				'Stardos Stencil',
				'Stint Ultra Condensed',
				'Stint Ultra Expanded',
				'Stoke',
				'Strait',
				'Stylish',
				'Sue Ellen Francisco',
				'Suez One',
				'Sumana',
				'Sunflower',
				'Sunshiney',
				'Supermercado One',
				'Sura',
				'Suranna',
				'Suravaram',
				'Suwannaphum',
				'Swanky and Moo Moo',
				'Syncopate',
				'Tajawal',
				'Tangerine',
				'Taprom',
				'Tauri',
				'Taviraj',
				'Teko',
				'Telex',
				'Tenali Ramakrishna',
				'Tenor Sans',
				'Text Me One',
				'Thasadith',
				'The Girl Next Door',
				'Tienne',
				'Tillana',
				'Timmana',
				'Tinos',
				'Titan One',
				'Titillium Web',
				'Trade Winds',
				'Trirong',
				'Trocchi',
				'Trochut',
				'Trykker',
				'Tulpen One',
				'Ubuntu',
				'Ubuntu Condensed',
				'Ubuntu Mono',
				'Ultra',
				'Uncial Antiqua',
				'Underdog',
				'Unica One',
				'UnifrakturCook',
				'UnifrakturMaguntia',
				'Unkempt',
				'Unlock',
				'Unna',
				'VT323',
				'Vampiro One',
				'Varela',
				'Varela Round',
				'Vast Shadow',
				'Vesper Libre',
				'Vibur',
				'Vidaloka',
				'Viga',
				'Voces',
				'Volkhov',
				'Vollkorn',
				'Vollkorn SC',
				'Voltaire',
				'Waiting for the Sunrise',
				'Wallpoet',
				'Walter Turncoat',
				'Warnes',
				'Wellfleet',
				'Wendy One',
				'Wire One',
				'Work Sans',
				'Yanone Kaffeesatz',
				'Yantramanav',
				'Yatra One',
				'Yellowtail',
				'Yeon Sung',
				'Yeseva One',
				'Yesteryear',
				'Yrsa',
				'ZCOOL KuaiLe',
				'ZCOOL QingKe HuangYou',
				'ZCOOL XiaoWei',
				'Zeyada',
				'Zilla Slab',
				'Zilla Slab Highlight',
			)
		);
	}

endif;

/*---------------------------------------------------------------------------------------------------------------------------------*/

if ( ! function_exists( 'rdcode_is_woocommerce' ) ) :

	function rdcode_is_woocommerce() {
		return apply_filters( 'is_woocommerce', ( is_shop() || is_product_taxonomy() || is_product() ) ? true : false ); 
	}

endif;

if ( ! function_exists( 'rdcode_wp_body_open' ) ) :
	/**
	 * Shim for sites older than 5.2.
	 *
	 * @link https://core.trac.wordpress.org/ticket/12563
	 */
	function rdcode_wp_body_open() {
		do_action( 'wp_body_open' );
	}
endif;